@@ -109,7 +109,13 @@ namespace MonoDevelop.Debugger.Gdb
 				
 				// Initialize the terminal
 				RunCommand ("-inferior-tty-set", Escape (tty));
-				RunCommand ("-file-exec-and-symbols", Escape (startInfo.Command));
+				
+				try {
+					RunCommand ("-file-exec-and-symbols", Escape (startInfo.Command));
+				} catch {
+					FireTargetEvent (TargetEventType.TargetExited, null);
+					throw;
+				}
 
 				RunCommand ("-environment-directory", Escape (startInfo.WorkingDirectory));
 				
@@ -453,7 +459,7 @@ namespace MonoDevelop.Debugger.Gdb
 			return list.ToArray ();
 		}
 		
-		protected override ProcessInfo[] OnGetPocesses ()
+		protected override ProcessInfo[] OnGetProcesses ()
 		{
 			ProcessInfo p = new ProcessInfo (0, currentProcessName);
 			return new ProcessInfo [] { p };
